CompressionLevel enum

Enum representing different levels of compression for media files.

Inheritance
Available extensions

Values

low → const CompressionLevel

low for 300 KB

medium → const CompressionLevel

medium for 1024 KB

high → const CompressionLevel

high for 5120 KB

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSize int

Available on CompressionLevel, provided by the CompressionSize extension

target size is for compression level
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CompressionLevel>
A constant List of the values in this enum, in order of their declaration.